(* Pager *)
(* $Id$ *)
(* TODO: Add a page_if_necessary function. *)

let call f =
  let old_behavior = Sys.signal
    Sys.sigpipe (Sys.Signal_handle (fun _ -> raise End_of_file))
  in
  let restore () = Sys.set_signal Sys.sigpipe old_behavior in
  let cmd = Config.current#get_string "cli.commands.pager" in
  let close oc =
    Sys.set_signal Sys.sigpipe Sys.Signal_ignore;
    begin
    match Unix.close_process_out oc with
    | Unix.WEXITED(rc) ->
      if rc <> 0 then
        Printf.printf "Pager command (%S) failed with code %d" cmd rc
      else
        ()
    | Unix.WSIGNALED(sg) ->
        Printf.printf "Pager command (%S) exited with signal %d" cmd sg
    | Unix.WSTOPPED(sg) ->
        Printf.printf "Pager command (%S) stopped with signal %d" cmd sg
    end
  in
  try
    let oc = Unix.open_process_out cmd in
    try
      f oc;
      close oc
    with
    | x -> close_out_noerr oc; close oc; raise x
  with
  | End_of_file -> restore ();
  | x -> restore (); raise x
;;

let page text = call (fun oc -> output_string oc text);;

let page_if_necessary text =
  if !Opt.use_pager & Util.count_lines text + 1 > !Opt.rows then
    call (fun oc -> output_string oc text)
  else
    print_string text
;;
