module SS : sig type t = string * string val compare : 'a -> 'a -> int end
module SSM :
  sig
    type key = SS.t
    type 'a t = 'a Map.Make(SS).t
    val empty : 'a t
    val is_empty : 'a t -> bool
    val add : key -> 'a -> 'a t -> 'a t
    val find : key -> 'a t -> 'a
    val remove : key -> 'a t -> 'a t
    val mem : key -> 'a t -> bool
    val iter : (key -> 'a -> unit) -> 'a t -> unit
    val map : ('a -> 'b) -> 'a t -> 'b t
    val mapi : (key -> 'a -> 'b) -> 'a t -> 'b t
    val fold : (key -> 'a -> 'b -> 'b) -> 'a t -> 'b -> 'b
    val compare : ('a -> 'a -> int) -> 'a t -> 'a t -> int
    val equal : ('a -> 'a -> bool) -> 'a t -> 'a t -> bool
  end
module IM :
  sig
    type key = int
    type +'a t
    val empty : 'a t
    val is_empty : 'a t -> bool
    val add : key -> 'a -> 'a t -> 'a t
    val find : key -> 'a t -> 'a
    val remove : key -> 'a t -> 'a t
    val mem : key -> 'a t -> bool
    val iter : (key -> 'a -> unit) -> 'a t -> unit
    val map : ('a -> 'b) -> 'a t -> 'b t
    val mapi : (key -> 'a -> 'b) -> 'a t -> 'b t
    val fold : (key -> 'a -> 'b -> 'b) -> 'a t -> 'b -> 'b
    val compare : ('a -> 'a -> int) -> 'a t -> 'a t -> int
    val equal : ('a -> 'a -> bool) -> 'a t -> 'a t -> bool
  end
module type BIG_SET =
  sig
    type t
    type elt = int
    val fold : (int -> 'a -> 'a) -> t -> 'a -> 'a
    val empty : t
    val union : t -> t -> t
    val diff : t -> t -> t
    val inter : t -> t -> t
    val add : int -> t -> t
    val cardinal : t -> int
    val is_empty : t -> bool
    val elements : t -> int list
  end
module type SMALL_SET =
  sig
    type t
    type elt = int
    val fold : (int -> 'a -> 'a) -> t -> 'a -> 'a
    val empty : t
    val union : t -> t -> t
    val diff : t -> t -> t
    val inter : t -> t -> t
    val add : int -> t -> t
    val cardinal : t -> int
    val is_empty : t -> bool
    val elements : t -> int list
    val shift : int
    val mask : int
  end
module type LENGTH_PARAM =
  sig val shift : int val mask : int val count : int end
module Set64 : SMALL_SET
module Arrayified_small_set :
  functor (S : SMALL_SET) -> functor (L : LENGTH_PARAM) -> SMALL_SET
module Mapified_set : functor (S : SMALL_SET) -> BIG_SET
module ASS64 :
  sig
    type t
    type elt = int
    val fold : (int -> 'a -> 'a) -> t -> 'a -> 'a
    val empty : t
    val union : t -> t -> t
    val diff : t -> t -> t
    val inter : t -> t -> t
    val add : int -> t -> t
    val cardinal : t -> int
    val is_empty : t -> bool
    val elements : t -> int list
    val shift : int
    val mask : int
  end
module IS :
  sig
    type t = Mapified_set(ASS64).t
    type elt = int
    val fold : (int -> 'a -> 'a) -> t -> 'a -> 'a
    val empty : t
    val union : t -> t -> t
    val diff : t -> t -> t
    val inter : t -> t -> t
    val add : int -> t -> t
    val cardinal : t -> int
    val is_empty : t -> bool
    val elements : t -> int list
  end
module SM :
  sig
    type key = String.t
    type 'a t = 'a Map.Make(String).t
    val empty : 'a t
    val is_empty : 'a t -> bool
    val add : key -> 'a -> 'a t -> 'a t
    val find : key -> 'a t -> 'a
    val remove : key -> 'a t -> 'a t
    val mem : key -> 'a t -> bool
    val iter : (key -> 'a -> unit) -> 'a t -> unit
    val map : ('a -> 'b) -> 'a t -> 'b t
    val mapi : (key -> 'a -> 'b) -> 'a t -> 'b t
    val fold : (key -> 'a -> 'b -> 'b) -> 'a t -> 'b -> 'b
    val compare : ('a -> 'a -> int) -> 'a t -> 'a t -> int
    val equal : ('a -> 'a -> bool) -> 'a t -> 'a t -> bool
  end
module SSet :
  sig
    type elt = String.t
    type t = Set.Make(String).t
    val empty : t
    val is_empty : t -> bool
    val mem : elt -> t -> bool
    val add : elt -> t -> t
    val singleton : elt -> t
    val remove : elt -> t -> t
    val union : t -> t -> t
    val inter : t -> t -> t
    val diff : t -> t -> t
    val compare : t -> t -> int
    val equal : t -> t -> bool
    val subset : t -> t -> bool
    val iter : (elt -> unit) -> t -> unit
    val fold : (elt -> 'a -> 'a) -> t -> 'a -> 'a
    val for_all : (elt -> bool) -> t -> bool
    val exists : (elt -> bool) -> t -> bool
    val filter : (elt -> bool) -> t -> t
    val partition : (elt -> bool) -> t -> t * t
    val cardinal : t -> int
    val elements : t -> elt list
    val min_elt : t -> elt
    val max_elt : t -> elt
    val choose : t -> elt
    val split : elt -> t -> t * bool * t
  end
val decompose_line : string -> string * string
val first_non_space : string -> int
class paragraph_folder :
  object
    method add_line : string -> unit
    method add_string : string -> unit
    method get : string
    method output : out_channel -> unit
    method reset : unit
  end
type ('a, 'b, 'c) dbg = {
  m : int;
  db : 'c array array;
  fields : string array;
  display_names : string array;
  package_field : int;
  version_field : int;
  index : int SSM.t;
  universe : IS.t;
  extra : 'b;
  methods : 'a;
}
type ('a, 'b) load_context = {
  field_index : (string, int) Hashtbl.t;
  non_canonical_names : (string, string) Hashtbl.t;
  mutable field_count : int;
  read_buffer : Buffer.t;
  mutable package_count : int;
  mutable packages : (int * 'b) list list;
  mutable ctx_extra : 'a;
}
class line_reader :
  in_channel ->
  object
    val b : Buffer.t
    val mutable i : int
    val mutable j : int
    val mutable offset : int
    val u : string
    method get_offset : int
    method input_line_with_offset : (string * int * int) option
    method refill : unit
    method reset : unit
  end
module type DBT =
  sig
    type extra
    type field
    class database_loader :
      object ('a)
        method create_load_context : (extra, field) load_context
        method display_name_of_field :
          ('a, extra, field) dbg -> int -> string
        method display_string_of_field :
          ('a, extra, field) dbg -> int -> string
        method empty_field : field
        method field_of_string : ('a, extra, field) dbg -> string -> int
        method find_package :
          ('a, extra, field) dbg -> string -> string -> int
        method get_count : ('a, extra, field) dbg -> int
        method get_display_names : ('a, extra, field) dbg -> string array
        method get_field : ('a, extra, field) dbg -> int -> int -> string
        method get_field_from_package :
          ('a, extra, field) dbg -> field array -> int -> string
        method get_fields : ('a, extra, field) dbg -> string array
        method get_package : ('a, extra, field) dbg -> int -> string array
        method get_universe : ('a, extra, field) dbg -> IS.t
        method is_field_empty : field -> bool
        method key :
          (extra, field) load_context -> field -> field -> string * string
        method key_of : ('a, extra, field) dbg -> int -> string * string
        method load :
          ?fast:bool ->
          ?progress:(string -> int -> unit) ->
          string list -> ('a, extra, field) dbg
        method load_single_file :
          fast:bool ->
          ?progress:(string -> int -> unit) ->
          (extra, field) load_context -> string -> unit
        method name_of : ('a, extra, field) dbg -> int -> string
        method package_field : ('a, extra, field) dbg -> int
        method string_of_field : ('a, extra, field) dbg -> int -> string
        method version_field : ('a, extra, field) dbg -> int
        method version_of : ('a, extra, field) dbg -> int -> string
      end
  end
class pf : paragraph_folder
module Misc :
  functor (DBT : DBT) ->
    sig
      type db = (DBT.database_loader, DBT.extra, DBT.field) dbg
      class paragraph_folder : pf
      module IS :
        sig
          type t = Mapified_set(ASS64).t
          type elt = int
          val fold : (int -> 'a -> 'a) -> t -> 'a -> 'a
          val empty : t
          val union : t -> t -> t
          val diff : t -> t -> t
          val inter : t -> t -> t
          val add : int -> t -> t
          val cardinal : t -> int
          val is_empty : t -> bool
          val elements : t -> int list
        end
      val field_of_string : db -> string -> int
      val string_of_field : db -> int -> string
      val display_name_of_field : db -> int -> string
      val display_string_of_field : db -> int -> string
      val name_of : db -> int -> string
      val version_of : db -> int -> string
      val key_of : db -> int -> string * string
      val find_package : db -> string -> string -> int
      val get_package : db -> int -> string array
      val get_field : db -> int -> int -> string
      val get_field_from_package : db -> DBT.field array -> int -> string
      val get_universe : db -> IS.t
      val get_fields : db -> string array
      val get_count : db -> int
      val get_display_names : db -> string array
      val package_field : db -> int
      val version_field : db -> int
    end
module type DB =
  sig
    module IS : BIG_SET
    type db
    and field
    val field_of_string : db -> string -> int
    val string_of_field : db -> int -> string
    val display_name_of_field : db -> int -> string
    val display_string_of_field : db -> int -> string
    val name_of : db -> int -> string
    val version_of : db -> int -> string
    val key_of : db -> int -> string * string
    val find_package : db -> string -> string -> int
    val get_package : db -> int -> string array
    val get_field : db -> int -> int -> string
    exception Malformed_line of string
    val find_database_files : (string * string) list -> string list
    val load :
      ?fast:bool -> ?progress:(string -> int -> unit) -> string list -> db
    val get_universe : db -> IS.t
    val get_fields : db -> string array
    val get_count : db -> int
    val get_display_names : db -> string array
    val package_field : db -> int
    val version_field : db -> int
    class paragraph_folder :
      object
        method add_line : string -> unit
        method add_string : string -> unit
        method get : string
        method output : out_channel -> unit
        method reset : unit
      end
  end
val create_load_context : 'a -> ('a, 'b) load_context
val binary_search : 'a array -> 'a -> int
exception Malformed_line of string
val collect_field_values : ('a, 'b, SSet.elt) dbg -> int -> SSet.elt list
val find_database_files : (string * string) list -> string list
class virtual ['a, 'b, 'c] database :
  object ('d)
    method virtual create_load_context : ('a, 'b) load_context
    method display_name_of_field : ('d, 'a, 'b) dbg -> int -> string
    method display_string_of_field : ('d, 'a, 'b) dbg -> int -> string
    method virtual empty_field : 'b
    method field_of_string : ('d, 'a, 'b) dbg -> string -> int
    method find_package : ('d, 'a, 'b) dbg -> string -> string -> int
    method get_count : ('d, 'a, 'b) dbg -> int
    method get_display_names : ('d, 'a, 'b) dbg -> string array
    method virtual get_field : ('d, 'a, 'b) dbg -> int -> int -> string
    method virtual get_field_from_package :
      ('d, 'a, 'b) dbg -> 'b array -> int -> string
    method get_fields : ('d, 'a, 'b) dbg -> string array
    method virtual get_package : ('d, 'a, 'b) dbg -> int -> string array
    method get_universe : ('d, 'a, 'b) dbg -> IS.t
    method virtual is_field_empty : 'b -> bool
    method private virtual key :
      ('a, 'b) load_context -> 'b -> 'b -> string * string
    method key_of : ('d, 'a, 'b) dbg -> int -> string * string
    method load :
      ?fast:bool ->
      ?progress:(string -> int -> unit) -> string list -> ('d, 'a, 'b) dbg
    method virtual load_single_file :
      fast:bool ->
      ?progress:(string -> int -> unit) ->
      ('a, 'b) load_context -> string -> unit
    method private virtual make_field :
      context:('a, 'b) load_context ->
      fast:bool ->
      file_id:'c ->
      start_offset:int ->
      end_offset:int ->
      field_name:string -> field_contents:string -> first_line:string -> 'b
    method virtual name_of : ('d, 'a, 'b) dbg -> int -> string
    method package_field : ('d, 'a, 'b) dbg -> int
    method private read_tags :
      ?fast:bool ->
      'c -> ('a, 'b) load_context -> reader:line_reader -> (int * 'b) list
    method string_of_field : ('d, 'a, 'b) dbg -> int -> string
    method version_field : ('d, 'a, 'b) dbg -> int
    method virtual version_of : ('d, 'a, 'b) dbg -> int -> string
  end
module V :
  sig
    type file =
      Virtual_strings.file = {
      name : string;
      fd : Unix.file_descr;
      mtime : float;
      range_low : int;
      range_high : int;
    }
    and pool =
      Virtual_strings.pool = {
      mutable count : int;
      mutable files : file array;
      mutable high : int;
    }
    and virtual_string =
      Virtual_strings.virtual_string = {
      beginning : int;
      length : int;
    }
    and t = Virtual_strings.t = Real of string | Virtual of virtual_string
    exception Error of string
    exception Not_real
    val sf : ('a, unit, string) format -> 'a
    val create : unit -> pool
    val add_file : pool -> string -> Unix.file_descr -> int
    val find_file : pool -> int -> int
    val make_virtual_string : pool -> int -> int -> int -> t
    val empty_string : t
    val is_empty : t -> bool
    val make_real_string : string -> t
    val get_real_string : 'a -> t -> string
    val get_string : pool -> t -> string
  end
module DBFS :
  sig
    class database_loader :
      object ('a)
        method create_load_context : (V.pool, V.t) load_context
        method display_name_of_field : ('a, V.pool, V.t) dbg -> int -> string
        method display_string_of_field :
          ('a, V.pool, V.t) dbg -> int -> string
        method empty_field : V.t
        method field_of_string : ('a, V.pool, V.t) dbg -> string -> int
        method find_package :
          ('a, V.pool, V.t) dbg -> string -> string -> int
        method get_count : ('a, V.pool, V.t) dbg -> int
        method get_display_names : ('a, V.pool, V.t) dbg -> string array
        method get_field : ('a, V.pool, V.t) dbg -> int -> int -> string
        method get_field_from_package :
          ('a, V.pool, V.t) dbg -> V.t array -> int -> string
        method get_fields : ('a, V.pool, V.t) dbg -> string array
        method get_package : ('a, V.pool, V.t) dbg -> int -> string array
        method get_universe : ('a, V.pool, V.t) dbg -> IS.t
        method is_field_empty : V.t -> bool
        method key :
          (V.pool, V.t) load_context -> V.t -> V.t -> string * string
        method key_of : ('a, V.pool, V.t) dbg -> int -> string * string
        method load :
          ?fast:bool ->
          ?progress:(string -> int -> unit) ->
          string list -> ('a, V.pool, V.t) dbg
        method load_single_file :
          fast:bool ->
          ?progress:(string -> int -> unit) ->
          (V.pool, V.t) load_context -> string -> unit
        method private make_field :
          context:(V.pool, V.t) load_context ->
          fast:bool ->
          file_id:int ->
          start_offset:int ->
          end_offset:int ->
          field_name:string ->
          field_contents:string -> first_line:string -> V.t
        method name_of : ('a, V.pool, V.t) dbg -> int -> string
        method package_field : ('a, V.pool, V.t) dbg -> int
        method private read_tags :
          ?fast:bool ->
          int ->
          (V.pool, V.t) load_context ->
          reader:line_reader -> (int * V.t) list
        method string_of_field : ('a, V.pool, V.t) dbg -> int -> string
        method version_field : ('a, V.pool, V.t) dbg -> int
        method version_of : ('a, V.pool, V.t) dbg -> int -> string
      end
    val find_database_files : (string * string) list -> string list
    exception Malformed_line of string
    val loader : database_loader
    val load :
      ?fast:bool ->
      ?progress:(string -> int -> unit) ->
      string list -> (database_loader, V.pool, V.t) dbg
    type dbi = (database_loader, V.pool, V.t) dbg
    type field = V.t
    class dl : database_loader
    module M :
      sig
        type db =
          (< create_load_context : (V.pool, V.t) load_context;
             display_name_of_field : ('a, V.pool, V.t) dbg -> int -> string;
             display_string_of_field : ('a, V.pool, V.t) dbg -> int -> string;
             empty_field : V.t;
             field_of_string : ('a, V.pool, V.t) dbg -> string -> int;
             find_package : ('a, V.pool, V.t) dbg -> string -> string -> int;
             get_count : ('a, V.pool, V.t) dbg -> int;
             get_display_names : ('a, V.pool, V.t) dbg -> string array;
             get_field : ('a, V.pool, V.t) dbg -> int -> int -> string;
             get_field_from_package : ('a, V.pool, V.t) dbg ->
                                      V.t array -> int -> string;
             get_fields : ('a, V.pool, V.t) dbg -> string array;
             get_package : ('a, V.pool, V.t) dbg -> int -> string array;
             get_universe : ('a, V.pool, V.t) dbg -> IS.t;
             is_field_empty : V.t -> bool;
             key : (V.pool, V.t) load_context ->
                   V.t -> V.t -> string * string;
             key_of : ('a, V.pool, V.t) dbg -> int -> string * string;
             load : ?fast:bool ->
                    ?progress:(string -> int -> unit) ->
                    string list -> ('a, V.pool, V.t) dbg;
             load_single_file : fast:bool ->
                                ?progress:(string -> int -> unit) ->
                                (V.pool, V.t) load_context -> string -> unit;
             name_of : ('a, V.pool, V.t) dbg -> int -> string;
             package_field : ('a, V.pool, V.t) dbg -> int;
             string_of_field : ('a, V.pool, V.t) dbg -> int -> string;
             version_field : ('a, V.pool, V.t) dbg -> int;
             version_of : ('a, V.pool, V.t) dbg -> int -> string >
           as 'a, V.pool, V.t)
          dbg
        class paragraph_folder : pf
        module IS :
          sig
            type t = Mapified_set(ASS64).t
            type elt = int
            val fold : (int -> 'a -> 'a) -> t -> 'a -> 'a
            val empty : t
            val union : t -> t -> t
            val diff : t -> t -> t
            val inter : t -> t -> t
            val add : int -> t -> t
            val cardinal : t -> int
            val is_empty : t -> bool
            val elements : t -> int list
          end
        val field_of_string : db -> string -> int
        val string_of_field : db -> int -> string
        val display_name_of_field : db -> int -> string
        val display_string_of_field : db -> int -> string
        val name_of : db -> int -> string
        val version_of : db -> int -> string
        val key_of : db -> int -> string * string
        val find_package : db -> string -> string -> int
        val get_package : db -> int -> string array
        val get_field : db -> int -> int -> string
        val get_field_from_package : db -> V.t array -> int -> string
        val get_universe : db -> IS.t
        val get_fields : db -> string array
        val get_count : db -> int
        val get_display_names : db -> string array
        val package_field : db -> int
        val version_field : db -> int
      end
    type db =
      (< create_load_context : (V.pool, V.t) load_context;
         display_name_of_field : ('a, V.pool, V.t) dbg -> int -> string;
         display_string_of_field : ('a, V.pool, V.t) dbg -> int -> string;
         empty_field : V.t;
         field_of_string : ('a, V.pool, V.t) dbg -> string -> int;
         find_package : ('a, V.pool, V.t) dbg -> string -> string -> int;
         get_count : ('a, V.pool, V.t) dbg -> int;
         get_display_names : ('a, V.pool, V.t) dbg -> string array;
         get_field : ('a, V.pool, V.t) dbg -> int -> int -> string;
         get_field_from_package : ('a, V.pool, V.t) dbg ->
                                  V.t array -> int -> string;
         get_fields : ('a, V.pool, V.t) dbg -> string array;
         get_package : ('a, V.pool, V.t) dbg -> int -> string array;
         get_universe : ('a, V.pool, V.t) dbg -> IS.t;
         is_field_empty : V.t -> bool;
         key : (V.pool, V.t) load_context -> V.t -> V.t -> string * string;
         key_of : ('a, V.pool, V.t) dbg -> int -> string * string;
         load : ?fast:bool ->
                ?progress:(string -> int -> unit) ->
                string list -> ('a, V.pool, V.t) dbg;
         load_single_file : fast:bool ->
                            ?progress:(string -> int -> unit) ->
                            (V.pool, V.t) load_context -> string -> unit;
         name_of : ('a, V.pool, V.t) dbg -> int -> string;
         package_field : ('a, V.pool, V.t) dbg -> int;
         string_of_field : ('a, V.pool, V.t) dbg -> int -> string;
         version_field : ('a, V.pool, V.t) dbg -> int;
         version_of : ('a, V.pool, V.t) dbg -> int -> string >
       as 'a, V.pool, V.t)
      dbg
    class paragraph_folder : pf
    module IS :
      sig
        type t = Mapified_set(ASS64).t
        type elt = int
        val fold : (int -> 'a -> 'a) -> t -> 'a -> 'a
        val empty : t
        val union : t -> t -> t
        val diff : t -> t -> t
        val inter : t -> t -> t
        val add : int -> t -> t
        val cardinal : t -> int
        val is_empty : t -> bool
        val elements : t -> int list
      end
    val field_of_string : M.db -> string -> int
    val string_of_field : M.db -> int -> string
    val display_name_of_field : M.db -> int -> string
    val display_string_of_field : M.db -> int -> string
    val name_of : M.db -> int -> string
    val version_of : M.db -> int -> string
    val key_of : M.db -> int -> string * string
    val find_package : M.db -> string -> string -> int
    val get_package : M.db -> int -> string array
    val get_field : M.db -> int -> int -> string
    val get_field_from_package : M.db -> V.t array -> int -> string
    val get_universe : M.db -> IS.t
    val get_fields : M.db -> string array
    val get_count : M.db -> int
    val get_display_names : M.db -> string array
    val package_field : M.db -> int
    val version_field : M.db -> int
  end
module DBRAM :
  sig
    class database_loader :
      object ('a)
        method create_load_context :
          ((string, string) Hashtbl.t, string) load_context
        method display_name_of_field :
          ('a, (string, string) Hashtbl.t, string) dbg -> int -> string
        method display_string_of_field :
          ('a, (string, string) Hashtbl.t, string) dbg -> int -> string
        method empty_field : string
        method field_of_string :
          ('a, (string, string) Hashtbl.t, string) dbg -> string -> int
        method find_package :
          ('a, (string, string) Hashtbl.t, string) dbg ->
          string -> string -> int
        method get_count :
          ('a, (string, string) Hashtbl.t, string) dbg -> int
        method get_display_names :
          ('a, (string, string) Hashtbl.t, string) dbg -> string array
        method get_field :
          ('a, (string, string) Hashtbl.t, string) dbg ->
          int -> int -> string
        method get_field_from_package :
          ('a, (string, string) Hashtbl.t, string) dbg ->
          string array -> int -> string
        method get_fields :
          ('a, (string, string) Hashtbl.t, string) dbg -> string array
        method get_package :
          ('a, (string, string) Hashtbl.t, string) dbg -> int -> string array
        method get_universe :
          ('a, (string, string) Hashtbl.t, string) dbg -> IS.t
        method is_field_empty : string -> bool
        method key :
          ((string, string) Hashtbl.t, string) load_context ->
          string -> string -> string * string
        method key_of :
          ('a, (string, string) Hashtbl.t, string) dbg ->
          int -> string * string
        method load :
          ?fast:bool ->
          ?progress:(string -> int -> unit) ->
          string list -> ('a, (string, string) Hashtbl.t, string) dbg
        method load_single_file :
          fast:bool ->
          ?progress:(string -> int -> unit) ->
          ((string, string) Hashtbl.t, string) load_context -> string -> unit
        method private make_field :
          context:((string, string) Hashtbl.t, string) load_context ->
          fast:bool ->
          file_id:string ->
          start_offset:int ->
          end_offset:int ->
          field_name:string ->
          field_contents:string -> first_line:string -> string
        method name_of :
          ('a, (string, string) Hashtbl.t, string) dbg -> int -> string
        method package_field :
          ('a, (string, string) Hashtbl.t, string) dbg -> int
        method private read_tags :
          ?fast:bool ->
          string ->
          ((string, string) Hashtbl.t, string) load_context ->
          reader:line_reader -> (int * string) list
        method string_of_field :
          ('a, (string, string) Hashtbl.t, string) dbg -> int -> string
        method version_field :
          ('a, (string, string) Hashtbl.t, string) dbg -> int
        method version_of :
          ('a, (string, string) Hashtbl.t, string) dbg -> int -> string
      end
    val find_database_files : (string * string) list -> string list
    exception Malformed_line of string
    val loader : database_loader
    val load :
      ?fast:bool ->
      ?progress:(string -> int -> unit) ->
      string list ->
      (database_loader, (string, string) Hashtbl.t, string) dbg
    type dbi = (database_loader, (string, string) Hashtbl.t, string) dbg
    type field = V.t
    class dl : database_loader
    module M :
      sig
        type db =
          (< create_load_context : ((string, string) Hashtbl.t, string)
                                   load_context;
             display_name_of_field : ('a, (string, string) Hashtbl.t, string)
                                     dbg -> int -> string;
             display_string_of_field : ('a, (string, string) Hashtbl.t,
                                        string)
                                       dbg -> int -> string;
             empty_field : string;
             field_of_string : ('a, (string, string) Hashtbl.t, string) dbg ->
                               string -> int;
             find_package : ('a, (string, string) Hashtbl.t, string) dbg ->
                            string -> string -> int;
             get_count : ('a, (string, string) Hashtbl.t, string) dbg -> int;
             get_display_names : ('a, (string, string) Hashtbl.t, string) dbg ->
                                 string array;
             get_field : ('a, (string, string) Hashtbl.t, string) dbg ->
                         int -> int -> string;
             get_field_from_package : ('a, (string, string) Hashtbl.t,
                                       string)
                                      dbg -> string array -> int -> string;
             get_fields : ('a, (string, string) Hashtbl.t, string) dbg ->
                          string array;
             get_package : ('a, (string, string) Hashtbl.t, string) dbg ->
                           int -> string array;
             get_universe : ('a, (string, string) Hashtbl.t, string) dbg ->
                            IS.t;
             is_field_empty : string -> bool;
             key : ((string, string) Hashtbl.t, string) load_context ->
                   string -> string -> string * string;
             key_of : ('a, (string, string) Hashtbl.t, string) dbg ->
                      int -> string * string;
             load : ?fast:bool ->
                    ?progress:(string -> int -> unit) ->
                    string list ->
                    ('a, (string, string) Hashtbl.t, string) dbg;
             load_single_file : fast:bool ->
                                ?progress:(string -> int -> unit) ->
                                ((string, string) Hashtbl.t, string)
                                load_context -> string -> unit;
             name_of : ('a, (string, string) Hashtbl.t, string) dbg ->
                       int -> string;
             package_field : ('a, (string, string) Hashtbl.t, string) dbg ->
                             int;
             string_of_field : ('a, (string, string) Hashtbl.t, string) dbg ->
                               int -> string;
             version_field : ('a, (string, string) Hashtbl.t, string) dbg ->
                             int;
             version_of : ('a, (string, string) Hashtbl.t, string) dbg ->
                          int -> string >
           as 'a, (string, string) Hashtbl.t, string)
          dbg
        class paragraph_folder : pf
        module IS :
          sig
            type t = Mapified_set(ASS64).t
            type elt = int
            val fold : (int -> 'a -> 'a) -> t -> 'a -> 'a
            val empty : t
            val union : t -> t -> t
            val diff : t -> t -> t
            val inter : t -> t -> t
            val add : int -> t -> t
            val cardinal : t -> int
            val is_empty : t -> bool
            val elements : t -> int list
          end
        val field_of_string : db -> string -> int
        val string_of_field : db -> int -> string
        val display_name_of_field : db -> int -> string
        val display_string_of_field : db -> int -> string
        val name_of : db -> int -> string
        val version_of : db -> int -> string
        val key_of : db -> int -> string * string
        val find_package : db -> string -> string -> int
        val get_package : db -> int -> string array
        val get_field : db -> int -> int -> string
        val get_field_from_package : db -> string array -> int -> string
        val get_universe : db -> IS.t
        val get_fields : db -> string array
        val get_count : db -> int
        val get_display_names : db -> string array
        val package_field : db -> int
        val version_field : db -> int
      end
    type db =
      (< create_load_context : ((string, string) Hashtbl.t, string)
                               load_context;
         display_name_of_field : ('a, (string, string) Hashtbl.t, string) dbg ->
                                 int -> string;
         display_string_of_field : ('a, (string, string) Hashtbl.t, string)
                                   dbg -> int -> string;
         empty_field : string;
         field_of_string : ('a, (string, string) Hashtbl.t, string) dbg ->
                           string -> int;
         find_package : ('a, (string, string) Hashtbl.t, string) dbg ->
                        string -> string -> int;
         get_count : ('a, (string, string) Hashtbl.t, string) dbg -> int;
         get_display_names : ('a, (string, string) Hashtbl.t, string) dbg ->
                             string array;
         get_field : ('a, (string, string) Hashtbl.t, string) dbg ->
                     int -> int -> string;
         get_field_from_package : ('a, (string, string) Hashtbl.t, string)
                                  dbg -> string array -> int -> string;
         get_fields : ('a, (string, string) Hashtbl.t, string) dbg ->
                      string array;
         get_package : ('a, (string, string) Hashtbl.t, string) dbg ->
                       int -> string array;
         get_universe : ('a, (string, string) Hashtbl.t, string) dbg -> IS.t;
         is_field_empty : string -> bool;
         key : ((string, string) Hashtbl.t, string) load_context ->
               string -> string -> string * string;
         key_of : ('a, (string, string) Hashtbl.t, string) dbg ->
                  int -> string * string;
         load : ?fast:bool ->
                ?progress:(string -> int -> unit) ->
                string list -> ('a, (string, string) Hashtbl.t, string) dbg;
         load_single_file : fast:bool ->
                            ?progress:(string -> int -> unit) ->
                            ((string, string) Hashtbl.t, string) load_context ->
                            string -> unit;
         name_of : ('a, (string, string) Hashtbl.t, string) dbg ->
                   int -> string;
         package_field : ('a, (string, string) Hashtbl.t, string) dbg -> int;
         string_of_field : ('a, (string, string) Hashtbl.t, string) dbg ->
                           int -> string;
         version_field : ('a, (string, string) Hashtbl.t, string) dbg -> int;
         version_of : ('a, (string, string) Hashtbl.t, string) dbg ->
                      int -> string >
       as 'a, (string, string) Hashtbl.t, string)
      dbg
    class paragraph_folder : pf
    module IS :
      sig
        type t = Mapified_set(ASS64).t
        type elt = int
        val fold : (int -> 'a -> 'a) -> t -> 'a -> 'a
        val empty : t
        val union : t -> t -> t
        val diff : t -> t -> t
        val inter : t -> t -> t
        val add : int -> t -> t
        val cardinal : t -> int
        val is_empty : t -> bool
        val elements : t -> int list
      end
    val field_of_string : db -> string -> int
    val string_of_field : db -> int -> string
    val display_name_of_field : db -> int -> string
    val display_string_of_field : db -> int -> string
    val name_of : db -> int -> string
    val version_of : db -> int -> string
    val key_of : db -> int -> string * string
    val find_package : db -> string -> string -> int
    val get_package : db -> int -> string array
    val get_field : db -> int -> int -> string
    val get_field_from_package : db -> string array -> int -> string
    val get_universe : db -> IS.t
    val get_fields : db -> string array
    val get_count : db -> int
    val get_display_names : db -> string array
    val package_field : db -> int
    val version_field : db -> int
  end
